@@ -7,6 +7,7 @@ import properties as properties
 import tools.convertion as conv
 import alm
 from ext import angles
+import os
 
 
 class gPixelMap(properties.Rendered):
@@ -15,22 +16,22 @@ class gPixelMap(properties.Rendered):
     Class with lmax, lmin, nx, np attributes for map rendering
     """
     name = None
-    temp = None
+    temp = True
 
     def __init__(self, **kwargs):
         # super(gPixelMap, self).__init__(**kwargs)
-        if self.name:
-            self.temp = False
-        else:
-            self.temp = True
         for k, v in kwargs.items():
             setattr(self, k, v)
-        pass
+        if self.name:
+            if os.path.exists(self.name) and self.name.count('tmp') < 1:
+                self.temp = False
 
     def unset_temp(self):
         self.temp = False
 
     def __setattr__(self, name, value):
+        if name == 'name' and os.path.exists(value) and value.count('tmp') < 1:
+            self.__dict__['temp'] = False
         try:
             return super(gPixelMap, self).__setattr__(name, value)
         except:
@@ -39,10 +40,9 @@ class gPixelMap(properties.Rendered):
     def from_alm(self):
         pass
 
-    def __del__(self):        # todo: test
+    def __del__(self):
         if self.temp:
-            pass
-            # os.remove(self.name)
+            os.remove(self.name)
 
     def show(self, **kwargs):
         # todo: test
@@ -160,3 +160,6 @@ class gPixelMap(properties.Rendered):
         attrs['name'] = masked_map_name
         masked_map = gPixelMap(**attrs)
         return masked_map
+
+    def to_gif(self, gif_name=None, **kwargs):
+        return conv.map_to_gif(self.name, gif_name=gif_name, **kwargs)
